
class LLabel : Gtk.Label {
    public LLabel (string label) {
        this.set_halign (Gtk.Align.START);
        this.label = label;
    }
    public LLabel.indent (string label) {
        this (label);
        this.margin_left = 10;
    }
    public LLabel.markup (string label){
        this (label);
        this.use_markup = true;
    }
    public LLabel.r (string label){
        this.set_halign (Gtk.Align.END);
        this.label = label;
    }
    public LLabel.right_with_markup (string label){
        this.set_halign (Gtk.Align.END);
        this.use_markup = true;
        this.label = label;
    }
}

internal class translations {
    string name = _("Sharing Accounts");
}


public class SharingAccountsPlug : Pantheon.Switchboard.Plug {
    
    GLib.List<WebContracts.Contract> contracts;
    WebContracts.Contract current;
    
    public SharingAccountsPlug (string [] args){
        this.contracts = new GLib.List<WebContracts.Contract> ();
        
        if (Constants.TWITTER == "true")
            contracts.append (new WebContracts.Twitter    ());
        if (Constants.IMAGEBIN == "true")
            contracts.append (new WebContracts.Imagebin   ());
        if (Constants.PASTEBIN == "true")
            contracts.append (new WebContracts.Pastebin   ());
        if (Constants.VIDEOBIN == "true")
            contracts.append (new WebContracts.Videobin   ());
        if (Constants.GOOGLE_TRANSLATE == "true")
            contracts.append (new WebContracts.GoogleTranslate ());
        if (Constants.FLICKR == "true")
            contracts.append (new WebContracts.Flickr     ());
        if (Constants.IMGUR == "true")
            contracts.append (new WebContracts.Imgur      ());
        if (Constants.FACEBOOK == "true")
            contracts.append (new WebContracts.Facebook   ());
        if (Constants.GOOGLE_PLUS == "true")
            contracts.append (new WebContracts.GooglePlus ());
        if (Constants.YOUTUBE == "true")
            contracts.append (new WebContracts.Youtube    ());
        if (Constants.WIKIPEDIA == "true")
            contracts.append (new WebContracts.Wikipedia  ());
        if (Constants.GOOGLE_SEARCH == "true")
            contracts.append (new WebContracts.GoogleSearch ());
        
        if (!(args.length > 1)){ /*show ui*/
            var box  = new Gtk.Box   (Gtk.Orientation.HORIZONTAL, 0);
            var list = new Gtk.Box   (Gtk.Orientation.VERTICAL, 0);
            var view = new Gtk.Box   (Gtk.Orientation.VERTICAL, 0);
            var scrl = new Gtk.ScrolledWindow (null, null);
            
            scrl.add_with_viewport (list);
            scrl.width_request = 300;
            list.margin = 12;
            
            box.pack_start (scrl, false);
            box.pack_start (view);
            
            var cur_box   = new Gtk.Box (Gtk.Orientation.HORIZONTAL, 20);
            var cur_label = new Gtk.Label (_("Select a service"));
            var cur_image = new Gtk.Image.from_icon_name (
                "preferences-desktop-online-accounts", Gtk.IconSize.DIALOG);
            cur_image.pixel_size = 64;
            
            var attrs = new Pango.AttrList ();
            attrs.insert (new Pango.AttrFontDesc (
                Pango.FontDescription.from_string ("bold 25")));
            cur_label.set_attributes (attrs);
            
            cur_label.halign = Gtk.Align.START;
            cur_box.pack_start (cur_image, false);
            cur_box.pack_start (cur_label);
            
            view.pack_start (cur_box, false);
            view.margin = 30;
            
            for (var i=0;i<contracts.length ();i++) {
                contracts.nth_data (i).activated.connect ( (c) => {
                    if (this.current != null) {
                        this.current.item.get_style_context ().remove_class (Gtk.STYLE_CLASS_BUTTON);
                        view.remove (this.current.container);
                    }
                    this.current = c;
                    c.item.get_style_context ().add_class (Gtk.STYLE_CLASS_BUTTON);
                    c.item.get_style_context ().set_state (Gtk.StateFlags.ACTIVE);
                    c.item.get_style_context ().invalidate ();
                    view.add (c.container);
                    view.show_all ();
                    cur_label.label = c.name.label;
                    cur_image.icon_name = c.icon.icon_name;
                });
                list.pack_start (contracts.nth_data (i).item, false);
            }
            
            this.add (box);
        }else{
            for (var i=0;i<contracts.length ();i++){
                if (contracts.nth_data (i).identifier == args[1]){
                    contracts.nth_data (i).run (
                        File.new_for_commandline_arg (args[2]));
                }
            }
        }
    }
}

public static int main (string [] args){
    Gtk.init (ref args);
    var plug = new SharingAccountsPlug (args);
    plug.register ("Sharing Accounts");
    plug.show_all ();
    
    Gtk.main ();
    
    return 0;
}
